From 263569999cacfcfd281ed67ec7a33a1456af88bc Mon Sep 17 00:00:00 2001
From: Timothe Jost <timothe.jost@wanadoo.fr>
Date: Fri, 13 Sep 2024 15:23:40 +0200
Subject: [PATCH] just adding one more test

---
 src/pypelines/__init__.py | 2 +-
 tests/test_core.py        | 5 ++++-
 2 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/src/pypelines/__init__.py b/src/pypelines/__init__.py
index 37bc4b2..f0e272c 100644
--- a/src/pypelines/__init__.py
+++ b/src/pypelines/__init__.py
@@ -1,4 +1,4 @@
-__version__ = "0.0.74"
+__version__ = "0.0.75"
 
 from . import loggs
 from .pipes import *
diff --git a/tests/test_core.py b/tests/test_core.py
index b203022..71cbf45 100644
--- a/tests/test_core.py
+++ b/tests/test_core.py
@@ -177,7 +177,7 @@ def test_pypeline_call(request, pipeline_fixture_name: str, session):
 def test_pypeline_requirement_stack(request, pipeline_fixture_name: str, session):
     pipeline: Pipeline = request.getfixturevalue(pipeline_fixture_name)
 
     # before being resolved (called)
     assert pipeline.complex_pipe.another_name.requires == ["complex_pipe.my_step_name"]
 
     # expect no result is present on disk because we didn't check_requirements
@@ -185,3 +185,6 @@ def test_pypeline_requirement_stack(request, pipeline_fixture_name: str, session
         pipeline.complex_pipe.another_name.generate(session)
 
     assert pipeline.complex_pipe.another_name.generate(session, check_requirements=True) == 54
+
+    # now, requires has been resolved and contains instanciated step objects
+    assert pipeline.complex_pipe.another_name.requires == [pipeline.complex_pipe.my_step_name]
@@ -177,7 +177,7 @@ def test_pypeline_call(request, pipeline_fixture_name: str, session):
     pipeline: Pipeline = request.getfixturevalue(pipeline_fixture_name)
 
-    # before being resolved (called)
+    # before being resolved (called), requires is a list of string
     assert pipeline.complex_pipe.another_name.requires == ["complex_pipe.my_step_name"]
 
-- 
GitLab